import Navigation from "@/components/navigation";
import { trackLettingsInquiry } from "@/lib/facebook-pixel";
import SEOHead from "@/components/seo-head";
import Footer from "@/components/footer";
import { Button } from "@/components/ui/button";
import { Card, CardContent } from "@/components/ui/card";
import { Calendar, Clock, User, Phone, MessageCircle } from "lucide-react";
import { useEffect } from "react";
import Cal, { getCalApi } from "@calcom/embed-react";
import logoPath from "@assets/Untitled design (9).avif";

export default function LandlordsPage() {
  useEffect(() => {
    // Lazy load Cal.com API only when component mounts
    const loadCalApi = async () => {
      try {
        const cal = await getCalApi({"namespace":"lettings-valuation"});
        cal("ui", {"theme":"light","hideEventTypeDetails":false,"layout":"month_view"});
      } catch (error) {
        console.warn('Cal.com API failed to load:', error);
      }
    };
    
    // Delay Cal.com loading to prioritise critical content
    const timer = setTimeout(loadCalApi, 1000);
    return () => clearTimeout(timer);
  }, [])

  useEffect(() => {
    // Handle anchor scrolling on page load
    const hash = window.location.hash;
    if (hash) {
      const element = document.querySelector(hash);
      if (element) {
        setTimeout(() => {
          element.scrollIntoView({ behavior: 'smooth' });
        }, 100);
      }
    }
  }, [])

  const lettingsSchema = {
    "@context": "https://schema.org",
    "@type": "Service",
    "name": "Property Lettings and Management Services",
    "provider": {
      "@type": "RealEstateAgent",
      "name": "RG Property"
    },
    "description": "Professional property lettings and management services in Bristol and Cardiff. Competitive fees, tenant finding, full management, and 90-second rent payments.",
    "areaServed": ["Bristol", "Cardiff", "Bath", "Gloucester"],
    "offers": [
      {
        "@type": "Offer",
        "name": "Simply Let Package",
        "price": "475",
        "priceCurrency": "GBP"
      },
      {
        "@type": "Offer",
        "name": "Collect & Protect Package",
        "price": "10%",
        "priceCurrency": "GBP"
      },
      {
        "@type": "Offer",
        "name": "Full Management Package",
        "price": "10%",
        "priceCurrency": "GBP"
      }
    ]
  };

  return (
    <div className="min-h-screen bg-white">
      <SEOHead
        title="Property Lettings Bristol & Cardiff | Landlord Services from £475 | RG Property"
        description="Professional property lettings and management in Bristol and Cardiff. Tenant finding from £475, full management at 10%, 90-second rent payments. Book your free lettings valuation."
        keywords="property lettings Bristol, property lettings Cardiff, letting agents Bristol, letting agents Cardiff, landlord services Bristol, property management Cardiff, tenant finding Bristol, rent collection"
        canonicalUrl="https://www.rgproperty.co.uk/landlords"
        ogTitle="Property Lettings Bristol & Cardiff - Landlord Services from £475"
        ogDescription="Professional lettings and management services with competitive fees, tenant finding, full management, and 90-second rent payments in Bristol and Cardiff."
        schema={lettingsSchema}
      />
      <Navigation />
      
      {/* Hero Section */}
      <section className="py-16 lg:py-24 bg-gradient-to-br from-gray-900 to-gray-800 text-white">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="text-center">
            <h1 className="text-4xl lg:text-6xl font-bold mb-6">
              LET YOUR PROPERTY<br />
              <span className="text-red-500">THE RIGHT WAY</span>
            </h1>
            <p className="text-xl text-gray-300 mb-8 max-w-3xl mx-auto">
              Get your property let quickly and efficiently with our expert lettings team and competitive rates.
            </p>
            
            <div className="mb-12">
              <a href="#book-lettings-valuation" className="inline-block">
                <Button className="bg-red-600 hover:bg-red-700 text-white font-semibold py-3 px-8 rounded-lg transition-colors duration-200">
                  Get Free Valuation
                </Button>
              </a>
            </div>
          </div>
        </div>
      </section>
      
      {/* Loyalty Scheme Section */}
      <section className="py-16 lg:py-20 bg-gradient-to-br from-red-50 to-orange-50">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="grid lg:grid-cols-2 gap-12 items-center">
            {/* Left Column - Content */}
            <div>
              <h2 className="text-5xl lg:text-6xl font-bold text-red-600 mb-6">
                Loyalty<br />
                Scheme
              </h2>
              <p className="text-lg text-gray-700 mb-6">
                Tired of seeing fee increases?
              </p>
              <p className="text-gray-600 mb-6">
                At RG your fee goes down, and will NEVER go up. Every year on our Birthday (26th Aug) 
                Collect and Protect & Fully managed landlords will get a 0.25% reduction, and 
                Prestige Landlords will receive a 0.5% reduction. (T&Cs apply)
              </p>
              <p className="text-gray-600 mb-8">
                See how your fees reduce year over year with our loyalty program:
              </p>
            </div>

            {/* Right Column - Fee Reduction Visualization */}
            <div className="relative">
              <div className="grid grid-cols-1 gap-6">
                {/* Collect & Protect / Fully Managed */}
                <div className="bg-white rounded-lg shadow-lg p-6">
                  <h4 className="text-lg font-semibold text-gray-900 mb-4">Collect & Protect / Fully Managed</h4>
                  <div className="space-y-3">
                    <div className="flex justify-between items-center">
                      <span className="text-gray-600">Year 1</span>
                      <div className="flex items-center">
                        <div className="w-24 h-4 bg-red-500 rounded"></div>
                        <span className="ml-3 font-semibold">10.00%</span>
                      </div>
                    </div>
                    <div className="flex justify-between items-center">
                      <span className="text-gray-600">Year 2</span>
                      <div className="flex items-center">
                        <div className="w-20 h-4 bg-red-400 rounded"></div>
                        <span className="ml-3 font-semibold">9.75%</span>
                      </div>
                    </div>
                    <div className="flex justify-between items-center">
                      <span className="text-gray-600">Year 3</span>
                      <div className="flex items-center">
                        <div className="w-16 h-4 bg-red-300 rounded"></div>
                        <span className="ml-3 font-semibold">9.50%</span>
                      </div>
                    </div>
                    <div className="flex justify-between items-center">
                      <span className="text-gray-600">Year 4</span>
                      <div className="flex items-center">
                        <div className="w-12 h-4 bg-red-200 rounded"></div>
                        <span className="ml-3 font-semibold">9.25%</span>
                      </div>
                    </div>
                  </div>
                </div>

                {/* Prestige Landlords */}
                <div className="bg-white rounded-lg shadow-lg p-6">
                  <h4 className="text-lg font-semibold text-gray-900 mb-4">Prestige Landlords</h4>
                  <div className="space-y-3">
                    <div className="flex justify-between items-center">
                      <span className="text-gray-600">Year 1</span>
                      <div className="flex items-center">
                        <div className="w-24 h-4 bg-yellow-500 rounded"></div>
                        <span className="ml-3 font-semibold">12.00%</span>
                      </div>
                    </div>
                    <div className="flex justify-between items-center">
                      <span className="text-gray-600">Year 2</span>
                      <div className="flex items-center">
                        <div className="w-20 h-4 bg-yellow-400 rounded"></div>
                        <span className="ml-3 font-semibold">11.50%</span>
                      </div>
                    </div>
                    <div className="flex justify-between items-center">
                      <span className="text-gray-600">Year 3</span>
                      <div className="flex items-center">
                        <div className="w-16 h-4 bg-yellow-300 rounded"></div>
                        <span className="ml-3 font-semibold">11.00%</span>
                      </div>
                    </div>
                    <div className="flex justify-between items-center">
                      <span className="text-gray-600">Year 4</span>
                      <div className="flex items-center">
                        <div className="w-12 h-4 bg-yellow-200 rounded"></div>
                        <span className="ml-3 font-semibold">10.50%</span>
                      </div>
                    </div>
                  </div>
                </div>
              </div>
            </div>
          </div>
        </div>
      </section>

      {/* Even More Reasons Section */}
      <section className="py-16 lg:py-20 bg-gradient-to-br from-pink-50 to-red-50">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <h2 className="text-3xl lg:text-4xl font-bold text-center text-gray-900 mb-12">
            Even More Reasons to Choose Us...
          </h2>
          
          <div className="grid md:grid-cols-3 gap-8">
            {/* 7 Days a Week */}
            <Card className="text-center shadow-lg hover:shadow-xl transition-shadow duration-200">
              <CardContent className="p-8">
                <div className="bg-gray-100 rounded-full p-4 w-16 h-16 mx-auto mb-6 flex items-center justify-center">
                  <Calendar className="h-8 w-8 text-gray-600" />
                </div>
                <h3 className="text-xl font-semibold text-gray-900 mb-4">7 Days a Week</h3>
                <p className="text-gray-600 text-sm leading-relaxed">
                  Tired of missing out on perfect applicants because your current agent is only open Monday to Friday, 9-5?
                </p>
                <p className="text-gray-600 text-sm leading-relaxed mt-4">
                  We open 7 days a week for viewings and appointments. We also operate 24/7 for maintenance and have leveraged AI to save cost, which means more saving for you!
                </p>
              </CardContent>
            </Card>

            {/* 90 Second Payments */}
            <Card className="text-center shadow-lg hover:shadow-xl transition-shadow duration-200">
              <CardContent className="p-8">
                <div className="bg-orange-100 rounded-full p-4 w-16 h-16 mx-auto mb-6 flex items-center justify-center">
                  <Clock className="h-8 w-8 text-orange-600" />
                </div>
                <h3 className="text-xl font-semibold text-gray-900 mb-4">90 Second Payments</h3>
                <p className="text-gray-600 text-sm leading-relaxed">
                  Psst... here's an industry secret!
                </p>
                <p className="text-gray-600 text-sm leading-relaxed mt-4">
                  The reason your agent doesn't pay your rent right away is because of interest. The more time your money is in their account, the more interest they make.
                </p>
                <p className="text-gray-600 text-sm leading-relaxed mt-4 font-semibold">
                  We pay you in 90 seconds of receipt.
                </p>
              </CardContent>
            </Card>

            {/* One Point of Contact */}
            <Card className="text-center shadow-lg hover:shadow-xl transition-shadow duration-200">
              <CardContent className="p-8">
                <div className="bg-green-100 rounded-full p-4 w-16 h-16 mx-auto mb-6 flex items-center justify-center">
                  <MessageCircle className="h-8 w-8 text-green-600" />
                </div>
                <h3 className="text-xl font-semibold text-gray-900 mb-4">Your Property, One Person</h3>
                <p className="text-gray-600 text-sm leading-relaxed">
                  Fed up with the endless phone tag? Sick of being bounced around departments?
                </p>
                <p className="text-gray-600 text-sm leading-relaxed mt-4">
                  Why speak to Sarah from head office who's never seen your property, when you could chat directly with your local expert?
                </p>
                <p className="text-red-600 text-sm leading-relaxed mt-4 font-semibold">
                  One property manager. One WhatsApp number. Zero runaround.
                </p>
              </CardContent>
            </Card>
          </div>
        </div>
      </section>

      {/* Fees and Services Section */}
      <section className="py-16 lg:py-20 bg-gray-900">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          {/* Header */}
          <div className="text-center mb-12">
            <h2 className="text-3xl font-bold text-white mb-6">Fees and Services</h2>


          </div>

          {/* Services Grid */}
          <div className="grid md:grid-cols-2 lg:grid-cols-4 gap-6">
            {/* Simply Let */}
            <Card className="shadow-lg">
              <CardContent className="p-6 text-center flex flex-col h-full">
                <div className="mb-6">
                  <div className="text-4xl font-bold text-gray-900 mb-1 flex items-center justify-center gap-2">£475 <span className="text-lg text-gray-600">+VAT</span></div>
                  <div className="bg-red-600 text-white px-3 py-1 text-xs font-semibold">
                    SIMPLY LET
                  </div>
                </div>
                
                <p className="text-sm text-gray-600 mb-6">
                  For experienced landlords who just need a tenant found.
                </p>
                
                <div className="text-left space-y-2 mb-6 flex-grow">
                  <ul className="text-sm text-gray-700 space-y-1">
                    <li>• Marketing</li>
                    <li>• Tenancy agreement</li>
                    <li>• Viewings</li>
                    <li>• Move in</li>
                    <li>• Advanced referencing</li>
                    <li>• Agreements & right to rent checks</li>
                    <li>• PEP & sanction checks</li>
                    <li>• References</li>
                  </ul>
                </div>
                
                <div className="border-t pt-4 mt-auto">
                  <p className="text-xs text-gray-600 mb-2">
                    <strong>Extras:</strong> Rent Collection & Notices: £50+ VAT per notice
                  </p>
                  <p className="text-xs text-gray-600 mb-2">
                    Get <strong>Simply Let Pro</strong> for only <strong>£595 +VAT</strong>:
                  </p>
                  <ul className="text-xs text-gray-600 space-y-1 mb-4">
                    <li>• Inventory</li>
                    <li>• Deposit Registration</li>
                    <li>• Premium Listing</li>
                  </ul>
                  <a href="#book-lettings-valuation">
                    <Button className="w-full bg-red-600 hover:bg-red-700 text-white font-semibold py-2 px-4 rounded-lg text-sm transition-colors duration-200">
                      Book Lettings Valuation
                    </Button>
                  </a>
                </div>
              </CardContent>
            </Card>

            {/* Collect & Protect */}
            <Card className="relative overflow-hidden shadow-lg">
              <div className="absolute top-0 right-0 bg-red-600 text-white px-3 py-1 text-xs font-bold">
                POPULAR
              </div>
              <CardContent className="p-6 text-center flex flex-col h-full">
                <div className="mb-6">
                  <div className="text-4xl font-bold text-gray-900 mb-1 flex items-center justify-center gap-2">6.5% <span className="text-lg text-gray-600">+VAT</span></div>
                  <div className="bg-gray-800 text-white px-3 py-1 text-xs font-semibold">
                    COLLECT & PROTECT
                  </div>
                </div>
                
                <p className="text-sm text-gray-600 mb-6">
                  Includes everything in Simply Let, plus full protection and rent collection. Never worry about a missed payment again.
                </p>
                
                <div className="text-left space-y-2 mb-6 flex-grow">
                  <ul className="text-sm text-gray-700 space-y-1">
                    <li>• Pro referencing, with advanced HMRC checks</li>
                    <li>• Inventory & check out reports</li>
                    <li>• Deposit registration</li>
                    <li>• Agreements & right to rent checks</li>
                    <li>• Rent collection & notices</li>
                    <li>• Rent protection guarantee</li>
                    <li>• Legal cover up to £100,000</li>
                    <li>• Full arrears chasing</li>
                    <li>• Rent paid same-day</li>
                    <li>• PEP & sanction checks</li>
                    <li>• Annual income and expenditure report</li>
                    <li>• Compliance monitoring</li>
                  </ul>
                </div>
                
                <div className="border-t pt-4 mt-auto">
                  <p className="text-xs text-gray-600 mb-2">
                    Setup cost: <strong>£400 + VAT</strong>
                  </p>
                  <p className="text-xs text-green-600 font-semibold mb-4">
                    ✅ No Hidden Fees
                  </p>
                  <a href="#book-lettings-valuation">
                    <Button className="w-full bg-red-600 hover:bg-red-700 text-white font-semibold py-2 px-4 rounded-lg text-sm transition-colors duration-200">
                      Book Lettings Valuation
                    </Button>
                  </a>
                </div>
              </CardContent>
            </Card>

            {/* Full Management */}
            <Card className="shadow-lg">
              <CardContent className="p-6 text-center flex flex-col h-full">
                <div className="mb-6">
                  <div className="text-4xl font-bold text-gray-900 mb-1 flex items-center justify-center gap-2">10% <span className="text-lg text-gray-600">+VAT</span></div>
                  <div className="bg-gray-600 text-white px-3 py-1 text-xs font-semibold">
                    FULL MANAGEMENT
                  </div>
                </div>
                
                <p className="text-sm text-gray-600 mb-6">
                  Hands-free management & compliance, with peace of mind built in.
                </p>
                
                <div className="text-left space-y-2 mb-6 flex-grow">
                  <ul className="text-sm text-gray-700 space-y-1">
                    <li>• Pro referencing</li>
                    <li>• Inventory & check out reports</li>
                    <li>• Deposit registration</li>
                    <li>• Agreements & right to rent checks</li>
                    <li>• Rent collection & notices</li>
                    <li>• Property management & compliance monitoring</li>
                    <li>• Annual renewals & rent review</li>
                    <li>• Annual income and expenditure report</li>
                    <li>• 3 property visits per year</li>
                    <li>• Rent & legal protection (£28/month or £300 one-off)</li>
                    <li>• PEP & sanction checks</li>
                    <li>• 7 days a week coverage</li>
                  </ul>
                </div>
                
                <div className="border-t pt-4 mt-auto">
                  <p className="text-xs text-gray-600 mb-2">
                    Setup cost: <strong>£425 + VAT</strong>
                  </p>
                  <p className="text-xs text-green-600 font-semibold mb-4">
                    ✅ No Hidden Fees
                  </p>
                  <a href="#book-lettings-valuation">
                    <Button className="w-full bg-red-600 hover:bg-red-700 text-white font-semibold py-2 px-4 rounded-lg text-sm transition-colors duration-200">
                      Book Lettings Valuation
                    </Button>
                  </a>
                </div>
              </CardContent>
            </Card>

            {/* Prestige */}
            <Card className="relative overflow-hidden shadow-lg">
              <div className="absolute top-0 right-0 bg-yellow-500 text-white px-3 py-1 text-xs font-bold">
                ULTIMATE
              </div>
              <CardContent className="p-6 text-center flex flex-col h-full">
                <div className="mb-6">
                  <div className="text-4xl font-bold text-gray-900 mb-1 flex items-center justify-center gap-2">12.50% <span className="text-lg text-gray-600">+VAT</span></div>
                  <div className="bg-yellow-500 text-white px-3 py-1 text-xs font-semibold">
                    PRESTIGE MANAGEMENT
                  </div>
                </div>
                
                <p className="text-sm text-gray-600 mb-6">
                  The most comprehensive service with premium perks.
                </p>
                
                <div className="text-left space-y-2 mb-6 flex-grow">
                  <ul className="text-sm text-gray-700 space-y-1">
                    <li>• Everything in full management</li>
                    <li>• Pro referencing</li>
                    <li>• Inventory & check out reports</li>
                    <li>• Deposit registration</li>
                    <li>• Agreements & right to rent checks</li>
                    <li>• Rent collection & notices</li>
                    <li>• Property management & compliance monitoring</li>
                    <li>• Annual renewals & rent review</li>
                    <li>• 4 property visits per year</li>
                    <li>• Annual income and expenditure report</li>
                    <li>• Rent & legal protection (up to £100,000)</li>
                    <li>• Rent protection coverage</li>
                    <li>• Dedicated point of contact</li>
                  </ul>
                </div>
                
                <div className="border-t pt-4 mt-auto">
                  <p className="text-xs text-gray-600 mb-2">
                    Setup cost: <strong>£450 + VAT</strong>
                  </p>
                  <p className="text-xs text-green-600 font-semibold mb-4">
                    ✅ No Hidden Fees
                  </p>
                  <a href="#book-lettings-valuation">
                    <Button className="w-full bg-red-600 hover:bg-red-700 text-white font-semibold py-2 px-4 rounded-lg text-sm transition-colors duration-200">
                      Book Lettings Valuation
                    </Button>
                  </a>
                </div>
              </CardContent>
            </Card>
          </div>
        </div>
      </section>

      {/* Terms Section */}
      <section className="py-16 lg:py-20 bg-gray-900">
        <div className="max-w-6xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="grid lg:grid-cols-2 gap-12 items-center">
            {/* Left Column - Logo */}
            <div className="text-center">
              <div className="flex items-center justify-center mb-6">
                <img src={logoPath} alt="RG Property" className="h-12 w-auto" />
              </div>
              
              <div className="flex items-center justify-center mb-4">
                <div className="text-yellow-400 text-2xl">★★★★★</div>
              </div>
              <p className="text-lg font-semibold text-white">100+ 5 STAR GOOGLE REVIEWS</p>
            </div>

            {/* Right Column - Terms */}
            <div>
              <p className="text-gray-300 mb-6">
                We know the other agents hide their fees and terms under layers of their website, even worse you'll have to beg them to tell you the truth...
              </p>
              <p className="text-xl text-white">
                Click <a href="https://www.rgproperty.co.uk/_files/ugd/a06166_7557ac54c135455bae96e8a5be42e632.pdf" target="_blank" rel="noopener noreferrer" className="text-red-400 underline font-semibold">here</a> to see our full terms document
              </p>
            </div>
          </div>
        </div>
      </section>

      {/* Book Free In-Person Lettings Valuation Section */}
      <section id="book-lettings-valuation" className="py-16 lg:py-20 bg-white">
        <div className="max-w-6xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="text-center mb-12">
            <h2 className="text-3xl lg:text-4xl font-bold text-gray-900 mb-4">Book Free In-Person Lettings Valuation</h2>
            <p className="text-lg text-gray-600">Schedule a comprehensive property assessment with our lettings experts</p>
          </div>

          <div className="grid lg:grid-cols-3 gap-12 items-start">
            {/* Calendar - Takes up 2 columns on desktop */}
            <div className="lg:col-span-2 bg-white rounded-lg shadow-lg p-6">
              <div className="flex items-center mb-6">
                <Calendar className="h-6 w-6 text-red-600 mr-3" />
                <h3 className="text-xl font-semibold text-gray-900">Select Your Appointment</h3>
              </div>
              <div className="min-h-[600px] w-full overflow-hidden">
                <Cal 
                  namespace="lettings-valuation"
                  calLink="r-g-property-bristol-qiqxb3/lettings-valuation"
                  style={{width:"100%",height:"100%",overflow:"scroll"}}
                  config={{"layout":"month_view","theme":"light"}}
                />
              </div>
            </div>

            {/* Benefits - Takes up 1 column on desktop */}
            <div className="lg:col-span-1 space-y-8">
              <Card className="shadow-lg">
                <CardContent className="p-8">
                  <h3 className="text-xl font-semibold text-gray-900 mb-4">What's Included</h3>
                  <div className="space-y-4">
                    <div className="flex items-start">
                      <div className="h-5 w-5 text-green-500 mr-3 mt-1 flex-shrink-0">✓</div>
                      <div>
                        <p className="font-medium text-gray-900">Property Assessment</p>
                        <p className="text-sm text-gray-600">Detailed evaluation of rental potential and market value</p>
                      </div>
                    </div>
                    <div className="flex items-start">
                      <div className="h-5 w-5 text-green-500 mr-3 mt-1 flex-shrink-0">✓</div>
                      <div>
                        <p className="font-medium text-gray-900">Market Analysis</p>
                        <p className="text-sm text-gray-600">Local rental market insights and comparable properties</p>
                      </div>
                    </div>
                    <div className="flex items-start">
                      <div className="h-5 w-5 text-green-500 mr-3 mt-1 flex-shrink-0">✓</div>
                      <div>
                        <p className="font-medium text-gray-900">Service Options</p>
                        <p className="text-sm text-gray-600">Explanation of our lettings packages and services</p>
                      </div>
                    </div>
                    <div className="flex items-start">
                      <div className="h-5 w-5 text-green-500 mr-3 mt-1 flex-shrink-0">✓</div>
                      <div>
                        <p className="font-medium text-gray-900">No Obligation</p>
                        <p className="text-sm text-gray-600">Free consultation with no pressure to commit</p>
                      </div>
                    </div>
                  </div>
                </CardContent>
              </Card>

              <Card className="shadow-lg bg-red-50 border-red-200">
                <CardContent className="p-8">
                  <h3 className="text-xl font-semibold text-red-900 mb-4">Why Choose RG?</h3>
                  <div className="space-y-3">
                    <div className="flex items-center">
                      <Phone className="h-5 w-5 text-red-600 mr-3" />
                      <span className="text-red-800">Local Bristol lettings experts</span>
                    </div>
                    <div className="flex items-center">
                      <User className="h-5 w-5 text-red-600 mr-3" />
                      <span className="text-red-800">Dedicated property manager</span>
                    </div>
                    <div className="flex items-center">
                      <MessageCircle className="h-5 w-5 text-red-600 mr-3" />
                      <span className="text-red-800">WhatsApp communication</span>
                    </div>
                  </div>
                </CardContent>
              </Card>
            </div>
          </div>
        </div>
      </section>

      <Footer />
    </div>
  );
}